Module: TkWrapper
- Defined in:
- lib/util/virtual_methods.rb,
lib/tkwrapper.rb,
lib/tkwrapper.rb,
lib/util/tk/tk.rb
Overview
wraps some code of Tk to make it more object oriented, provide new functionality and to ease usage
Defined Under Namespace
Modules: Util, VirtualMethods, Widgets
Constant Summary collapse
- Manager =
TkWrapper::Widgets::Base::Manager
- Widget =
TkWrapper::Widgets::Base::Widget